@@ -11,7 +11,7 @@ class DoxygenNode(nodes.Element):
 
 class DoxygenAutoNode(nodes.Element):
 
-    def __init__(self, auto_project_info, files, options, factories, state):
+    def __init__(self, auto_project_info, files, options, factories, state, lineno):
 
         nodes.Element.__init__(self, rawsource='', children=[], attributes={})
 
@@ -20,4 +20,5 @@ class DoxygenAutoNode(nodes.Element):
         self.options = options
         self.factories = factories
         self.state = state
+        self.lineno = lineno
 
